/* Copyright (C) 2023 FIAS Frankfurt Institute for Advanced Studies, Frankfurt / Main
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Felix Weiglhofer [committer] */
#include "UnpackChain.h"

using namespace cbm::algo;

void UnpackChain::Init()
{
  // Disable walk correction for now. 2022 data crashes unpacker with hardcoded 2021 params.
  fUnpack.SetApplyWalkCorrection(false);
  fUnpack.Init(std::vector<fles::SubsystemIdentifier> {
    fles::SubsystemIdentifier::STS,
    // fles::SubsystemIdentifier::MUCH,
    fles::SubsystemIdentifier::RPC, fles::SubsystemIdentifier::T0,
    // fles::SubsystemIdentifier::TRD,
    // fles::SubsystemIdentifier::TRD2D,
  });
}

Unpack::resultType UnpackChain::Run(const fles::Timeslice& timeslice)
{
  auto result = fUnpack(&timeslice);

  auto& digis = result.first.fData;

  L_(info) << "Timeslice contains " << digis.fSts.Size() << " STS Digis";
  L_(info) << "Timeslice contains " << digis.fTof.Size() << " TOF Digis";
  L_(info) << "Timeslice contains " << digis.fT0.Size() << " T0 Digis";

  return result;
}
